erc7730.lint package

Subpackages

Submodules

Module contents

class erc7730.lint.ERC7730Linter[source]View on GitHub

Bases: ABC

Linter for ERC-7730 descriptors, inspects a (structurally valid) descriptor and emits notes, warnings, or errors.

A linter may emit false positives or false negatives. It is up to the user to interpret the output.

abstract lint(descriptor: ResolvedERC7730Descriptor, out: OutputAdder) None[source]View on GitHub