erc7730.model.input.v2.context module
Object model for ERC-7730 v2 descriptors context section.
- pydantic model erc7730.model.input.v2.context.InputBindingContext[source]View on GitHub
Bases:
Model- field deployments: list[InputDeployment] [Required]
An array of deployments describing where the contract is deployed. The target contract (Tx to orfactory) MUST match one of those deployments.
- Constraints:
min_length = 1
- pydantic model erc7730.model.input.v2.context.InputContract[source]View on GitHub
Bases:
InputBindingContextThe contract binding context is a set constraints that are used to bind the ERC7730 file to a specific smart contract.
- Fields:
- field abi: Any | None = None
[Deprecated] ABI definition bound to this file.Continue providing it for backward compatibility only; new specs should rely on display formats.
- field addressMatcher: HttpUrl | None = None
An URL of a contract address matcher that should be used to match the contract address.
- field factory: InputFactory | None = None
A factory constraint is used to check whether the target contract is deployed by a specifiedfactory.
- pydantic model erc7730.model.input.v2.context.InputContractContext[source]View on GitHub
Bases:
ModelContract Binding Context.
The contract binding context is a set constraints that are used to bind the ERC7730 file to a specific smart contract.
- field contract: InputContract [Required]
The contract binding context is a set constraints that are used to bind the ERC7730 file to aspecific smart contract.
- pydantic model erc7730.model.input.v2.context.InputDeployment[source]View on GitHub
Bases:
ModelA deployment describing where the contract is deployed.
The target contract (Tx to or factory) MUST match one of those deployments.
- Fields:
- field address: validate, json_schema_input_type=PydanticUndefined)] [Required]
The deployment contract address.
- Constraints:
min_length = 42
max_length = 42
pattern = ^0x[a-fA-F0-9]+$
func = <function ErrorTypeLabel._validator.<locals>.validate at 0x7fb0a7945580>
json_schema_input_type = PydanticUndefined
- field chainId: int [Required]
The deployment EIP-155 chain id.
- pydantic model erc7730.model.input.v2.context.InputDomain[source]View on GitHub
Bases:
ModelEIP 712 Domain Binding constraint.
Each value of the domain constraint MUST match the corresponding eip 712 message domain value.
- Fields:
- pydantic model erc7730.model.input.v2.context.InputEIP712[source]View on GitHub
Bases:
InputBindingContextEIP 712 Binding.
The EIP-712 binding context is a set of constraints that must be verified by the message being signed.
- Fields:
- field domain: InputDomain | None = None
Each value of the domain constraint MUST match the corresponding eip 712 message domain value.
- pydantic model erc7730.model.input.v2.context.InputEIP712Context[source]View on GitHub
Bases:
ModelEIP 712 Binding.
The EIP-712 binding context is a set of constraints that must be verified by the message being signed.
- field eip712: InputEIP712 [Required]
The EIP-712 binding context is a set of constraints that must be verified by the message beingsigned.
- pydantic model erc7730.model.input.v2.context.InputFactory[source]View on GitHub
Bases:
ModelA factory constraint is used to check whether the target contract is deployed by a specified factory.
- field deployEvent: str [Required]
The event signature that the factory emits when deploying a new contract.
- field deployments: list[InputDeployment] [Required]
An array of deployments describing where the contract is deployed. The target contract (Tx to orfactory) MUST match one of those deployments.