erc7730.lint.v2 package
Submodules
Module contents
- class erc7730.lint.v2.ERC7730Linter[source]View on GitHub
Bases:
ABCLinter for ERC-7730 v2 descriptors, inspects a (structurally valid) resolved v2 descriptor and emits notes, warnings, or errors.
A linter may emit false positives or false negatives. It is up to the user to interpret the output.
- abstract lint(descriptor: ResolvedERC7730Descriptor, out: OutputAdder) None[source]View on GitHub
- final class erc7730.lint.v2.MultiLinter(linters: list[ERC7730Linter])[source]View on GitHub
Bases:
ERC7730LinterA linter that runs multiple v2 linters in sequence.
- lint(descriptor: ResolvedERC7730Descriptor, out: OutputAdder) None[source]View on GitHub