erc7730.lint.v2.path_schemas module
Utilities for computing schema paths from v2 resolved display formats.
These functions extract the set of data paths referenced by a v2 resolved format, which can then be compared against ABI-derived paths for validation.
- erc7730.lint.v2.path_schemas.compute_format_schema_paths(fmt: ResolvedFormat) FormatPaths[source]View on GitHub
Compute the sets of schema paths referred in a v2 ERC7730 Format section.
- Parameters:
fmt – resolved v2 $.display.format section
- Returns:
schema paths used by field formats