erc7730.model.input.v2.descriptor module
Package implementing an object model for ERC-7730 v2 input descriptors.
- This model represents descriptors before resolution phase:
URLs have been not been fetched yet
Contract addresses have not been normalized to lowercase
References have not been inlined
Constants have not been inlined
Field definitions have not been inlined
Nested fields have been flattened where possible
Selectors have been converted to 4 bytes form
- pydantic model erc7730.model.input.v2.descriptor.InputERC7730Descriptor[source]View on GitHub
Bases:
ModelAn ERC-7730 v2 Clear Signing descriptor.
This model is directly serializable back to the original JSON document.
Specification: https://github.com/LedgerHQ/clear-signing-erc7730-registry/tree/master/specs
JSON schema: https://github.com/LedgerHQ/clear-signing-erc7730-registry/blob/master/specs/erc7730-v2.schema.json
- Fields:
- field comment: str | None = None (alias '$comment')
An optional comment string that can be used to document the purpose of the file.
- field context: InputContractContext | InputEIP712Context [Required]
The binding context is a set of constraints that are used to bind the ERC7730 file to a specificstructured data being displayed. Currently, supported contexts include contract-specificconstraints or EIP712 message specific constraints.
- field display: InputDisplay [Required]
The display section contains all the information needed to format the data in a human readableway. It contains the constants and formatters used to display the data contained in the bound structure.
- field includes: str | None = None
An URL of another ERC 7730 file that should be merged into this one. Includes are merged into this file before analysis. This can be used to manage interfaces definitions without redundancy.
- field metadata: InputMetadata [Required]
The metadata section contains information about constant values relevant in the scope of thecurrent contract / message (as matched by the context section)
- field schema_: str | None = None (alias '$schema')
The schema that the document should conform to. This should be the URL of a version of the clear signing JSON schemas available under https://github.com/LedgerHQ/clear-signing-erc7730-registry/tree/master/specs