erc7730.model.resolved.v2.context module
Object model for ERC-7730 v2 resolved descriptors context section.
Specification: https://github.com/LedgerHQ/clear-signing-erc7730-registry/tree/master/specs JSON schema: https://github.com/LedgerHQ/clear-signing-erc7730-registry/blob/master/specs/erc7730-v2.schema.json
- pydantic model erc7730.model.resolved.v2.context.ResolvedBindingContext[source]View on GitHub
Bases:
Model- field deployments: list[ResolvedDeployment] [Required]
An array of deployments describing where the contract is deployed. The target contract (Tx to orfactory) MUST match one of those deployments.
- Constraints:
min_length = 1
- pydantic model erc7730.model.resolved.v2.context.ResolvedContract[source]View on GitHub
Bases:
ResolvedBindingContextThe contract binding context is a set constraints that are used to bind the ERC7730 file to a specific smart contract (resolved).
- Fields:
- field addressMatcher: str | None = None
A resolved address matcher that should be used to match the contract address.
- field factory: ResolvedFactory | None = None
A factory constraint is used to check whether the target contract is deployed by a specifiedfactory.
- pydantic model erc7730.model.resolved.v2.context.ResolvedContractContext[source]View on GitHub
Bases:
ModelContract Binding Context (resolved).
The contract binding context is a set constraints that are used to bind the ERC7730 file to a specific smart contract.
- field contract: ResolvedContract [Required]
The contract binding context is a set constraints that are used to bind the ERC7730 file to aspecific smart contract.
- pydantic model erc7730.model.resolved.v2.context.ResolvedDeployment[source]View on GitHub
Bases:
ModelA deployment describing where the contract is deployed (resolved).
The target contract (Tx to or factory) MUST match one of those deployments.
- Fields:
- field address: validate, json_schema_input_type=PydanticUndefined)] [Required]
The deployment contract address (normalized to lowercase).
- Constraints:
min_length = 42
max_length = 42
pattern = ^0x[a-f0-9]+$
func = <function ErrorTypeLabel._validator.<locals>.validate at 0x7fb0a7946340>
json_schema_input_type = PydanticUndefined
- field chainId: int [Required]
The deployment EIP-155 chain id.
- pydantic model erc7730.model.resolved.v2.context.ResolvedDomain[source]View on GitHub
Bases:
ModelEIP 712 Domain Binding constraint (resolved).
Each value of the domain constraint MUST match the corresponding eip 712 message domain value.
- Fields:
- pydantic model erc7730.model.resolved.v2.context.ResolvedEIP712[source]View on GitHub
Bases:
ResolvedBindingContextEIP 712 Binding (resolved).
The EIP-712 binding context is a set of constraints that must be verified by the message being signed.
- Fields:
- field domain: ResolvedDomain | None = None
Each value of the domain constraint MUST match the corresponding eip 712 message domain value.
- pydantic model erc7730.model.resolved.v2.context.ResolvedEIP712Context[source]View on GitHub
Bases:
ModelEIP 712 Binding (resolved).
The EIP-712 binding context is a set of constraints that must be verified by the message being signed.
- field eip712: ResolvedEIP712 [Required]
The EIP-712 binding context is a set of constraints that must be verified by the message beingsigned.
- pydantic model erc7730.model.resolved.v2.context.ResolvedFactory[source]View on GitHub
Bases:
ModelA factory constraint is used to check whether the target contract is deployed by a specified factory (resolved).
- field deployEvent: str [Required]
The event signature that the factory emits when deploying a new contract.
- field deployments: list[ResolvedDeployment] [Required]
An array of deployments describing where the contract is deployed. The target contract (Tx to orfactory) MUST match one of those deployments.